from setuptools import setup, find_packages

setup(
    name='regression_omari',
    version='0.1',
    packages=find_packages(),
    description='A simple linear regression model implemented from scratch.',
    author='Your Name',
    author_email='your.email@example.com',
    url='https://github.com/yourusername/regression_pkg',  # Replace with your GitHub repo
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
